## Turing SDK Examples
---

### Quick Start example
*  [`quickstart/quick_start.py`](./quickstart/quick_start.py)  
   Basic example to introduce Turing SDK concepts and usage patterns  
   **Usage:**
   ```python
   python quick_start.py \
       --turing_api=<URL of Turing API> \ 
       --project=<your_project_name>
   ```
   
### Other examples
*  [`batch_job/batch_job.py`](batch_job/batch_job.py)  
   Example that demonstrates how to configure and submit a batch ensembling job
   with Turing
   **Usage:**
   ```python
   python batch_job.py \
       --turing_api=<URL of Turing API> \ 
       --project=<your_project_name>
   ```